import json
import requests
from collections import namedtuple
try:
    from types import SimpleNamespace as Namespace
except ImportError:
    from argparse import Namespace


class Kkiapay:

    BASE_URL = "https://api.kkiapay.me"
    SANDBOX_URL = "https://api-sandbox.kkiapay.me"

    def __init__(self, public_key, private_key, secret, sandbox=False):
        self.secret = secret
        self.sandbox = sandbox
        self.public_key = public_key
        self.private_key = private_key
        self.headers = {
            "Accept": "application/json",
            "X-SECRET-KEY": self.secret,
            "X-API-KEY": self.public_key,
            "X-PRIVATE-KEY": self.private_key,
        }
        self.url = self.SANDBOX_URL if self.sandbox else self.BASE_URL


    def verify_transaction(self, transaction_id):
        self.url += "/api/v1/transactions/status"
        payload = {"transactionId": transaction_id}
        r = requests.post(self.url, data=payload, headers=self.headers)

        return json.loads(r.text, object_hook=lambda d: namedtuple('KkiapayTransaction', d.keys())(*d.values()))

    def refund_transaction(self, transaction_id):
        self.url += "/api/v1/transactions/revert"
        payload = {"transactionId": transaction_id}
        r = requests.post(self.url, data=payload, headers=self.headers)
        return r.text

    def setup_payout(self, options):
        self.url += "/merchant/payouts/schedule"
        r = requests.post(self.url, data=options, headers=self.headers)
        return r.text




from .context import kkiapay
from kkiapay import Kkiapay
import requests_mock, requests

def setup_module(module):
    """ setup any state specific to the execution of the given module."""

def teardown_module(module):
    """ teardown any state that was previously setup with a setup_module
    method.
    """

class TestKkiapay(object):

    def test_answer(self, requests_mock):
        pass
        # requests_mock.get("http://123-fake-api.com", text="Hello!")
        # requests_mock.get("http://123-fake-api.com", text="Hello!")
        # response = requests.get("http://123-fake-api.com")

        # assert response.text == "Hello!"



    # k = Kkiapay('a1fc2c00410911e991519dc1901933da', 'pk_a1fc5310410911e991519dc1901933da', 'sk_a1fc5311410911e991519dc1901933da')

    # r = k.verify_transaction('qM0enu1Czb')


import os
import setuptools

with open('requirements.txt') as f:
    required = f.read().splitlines()

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="kkiapay",
    version="0.0.5",
    author="Junior Gantin",
    author_email="nioperas06@gmail.com",
    description="Community-driven Admin KkiaPay Sdk for Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/PythonBenin/kkiapay-python",
    packages=setuptools.find_packages(),
    install_requires=required,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
